@@ -10,7 +10,7 @@ our %Lexicon = (
     test_default_value => 'My Default',
     label_foo          => 'Foo label',
     label_form_bar     => 'Bar label',
-    form_htmlformfu_myvalidator_error => 'myvalidator error!'
+    form_validator_htmlformfu_myvalidator => 'myvalidator error!'
 );
 
 1;
